@@ -30,15 +30,11 @@ stop()
 jj <- knotoptim(filename,
                 symobj = symk11,
                 ou   = ouk11,
-                prob=0,
+                prob = 0,
                 iterlim=1000, print.level=2
+#                control=list(trace=100,maxit=100000), useNLM=FALSE
                 )
 
-
-
-write_svg(jj,filename)
-save(jj,file=sub('.svg','.data',filename))
-
-stop()
-
+write_svg(jj,filename,safe=FALSE)
+dput(jj,file=sub('.svg','.S',filename))
 
