@@ -30,13 +30,13 @@ symsat <- symmetry_object(x=a, xver=19)
 jj <- knotoptim(filename,
                 symobj = symsat,
                 ou   = ousat,
-                prob=0,
-                ## iterlim=1,print.level=2,         # these arguments for nlm()
-                control=list(trace=100,maxit=1000), # these arguments for optim()
+                prob = 0,
+#           iterlim=1000,print.level=2,         # these arguments for nlm()
+                control=list(trace=9000,maxit=10000), # these arguments for optim()
                 useNLM=FALSE
                 )
 
-write_svg(jj,filename)
-save(jj,file=sub('.svg','.data',filename))
+write_svg(jj,filename,safe=FALSE)
+dput(jj,file=sub('.svg','.S',filename))
 
 
